Crate powers_rs

Crate powers_rs 

Modules

graph
input
output
scenario
sddp
Implementation of the Stochastic Dual Dynamic Programming (SDDP) algorithm for the hydrothermal dispatch problem. In exchange for the simplified power system and state definition, some “smart” optimizations and features are already considered in this code.
subproblem
utils

Structs

InputArgs

Functions

run