Module graph

Module graph 

Structs

DirectedGraph
A simple directed graph structure for using in the SDDP algorithm, to make the temporal decomposition of the problem, store the power system configurations, the built policies and simulation results.
Node

Enums

GraphBuildingError