Structs
- Constraints
- Helper accessor for indexing desired variables in each subproblem
- Realization
- Subproblem
- A subproblem that contains a solver model and is associated to a single node in the computing graph
- Variables
- Helper accessor for indexing desired variables in each subproblem