pub struct Subproblem {
pub model: Option<Model>,
pub state: Box<dyn State>,
pub variables: Variables,
pub constraints: Constraints,
}Expand description
A subproblem that contains a solver model and is associated to a single node in the computing graph
Fields
model: Option<Model>state: Box<dyn State>variables: Variablesconstraints: ConstraintsImplementations
Sourceimpl Subproblem
impl Subproblem
pub fn new( system: &System, state_choice: &str, load_stochastic_process: &Box<dyn StochasticProcess>, inflow_stochastic_process: &Box<dyn StochasticProcess>, ) -> Self
pub fn update_with_current_trajectory( &mut self, realizations: Vec<&Realization>, )
pub fn update_with_current_realization(&mut self, realization: &Realization)
pub fn compute_new_cut( &self, forward_trajectory: &[&Realization], branching_realizations: &Vec<Realization>, risk_measure: &Box<dyn RiskMeasure>, ) -> CutStatePair
pub fn add_cut_and_evaluate_cut_selection( &mut self, cut_state_pair: CutStatePair, future_cost_function: Arc<Mutex<FutureCostFunction>>, )
pub fn realize_uncertainties( &mut self, noises: &SampledBranchingNoises, load_stochastic_process: &Box<dyn StochasticProcess>, inflow_stochastic_process: &Box<dyn StochasticProcess>, realization_container: &mut Realization, ) -> Result<(), String>