Module utils

Module utils 

Functions

dot_product
Helper function for evaluating the dot product between two vectors. This implementation expect f64 slices and does not use any kind of SSE operations. The slices are expected to have the same length.
mean
Helper function for evaluating the average of a series of values.
standard_deviation
Helper function for evaluating the standard deviation of a series of values.
uniform_prob_by_count
Helper function for generating an uniform probability distribution from a given number of samples.