Module graph
powers_
rs
0.2.0
Module graph
Module Items
Structs
Enums
In crate powers_
rs
powers_rs
Module
graph
Structs

Directed
Graph
A simple directed graph structure for using in the SDDP algorithm, to make the temporal decomposition of the problem, store the power system configurations, the built policies and simulation results.
Node
Enums

Graph
Building
Error