Module utils
powers_
rs
0.2.0
Module utils
Module Items
Functions
In crate powers_
rs
powers_rs
Module
utils
Functions

dot_
product
Helper function for evaluating the dot product between two vectors. This implementation expect f64 slices and does not use any kind of SSE operations. The slices are expected to have the same length.
mean
Helper function for evaluating the average of a series of values.
standard_
deviation
Helper function for evaluating the standard deviation of a series of values.
uniform_
prob_
by_
count
Helper function for generating an uniform probability distribution from a given number of samples.